@@ -153,7 +153,7 @@ class Parser(object):
         p[0] = ast.Method('schedule', self, p.lineno(1), p[2][0], args=[p[1]] + p[2][1], kwargs=p[2][2])
 
     def p_task_when(self, p):
-        '''stmt : WHEN figure_expression  suite'''
+        '''stmt : WHEN figure_expression suite'''
         p[0] = ast.Method("when", parser=self, lineno=p.lineno(1), suite=p[3], args=(p[2], ))
 
     def p_task_after(self, p):
@@ -283,12 +283,6 @@ class Parser(object):
         p[1]['paths'] = p[2].path.split('.')
         p[0] = p[1]
 
-    # def p_figure_aggexps(self, p):
-    #     '''figaggexps : figaggexp
-    #                   | figaggexps AND figaggexp
-    #                   | figaggexps OR  figaggexp'''
-    #     pass
-
     def p_figure(self, p):
         '''figure : agg offit unique paths figexps sort time
                   | agg offit unique paths         sort time
@@ -307,14 +301,16 @@ class Parser(object):
                 _['paths'] = p[x].path.split('.')
 
         _.pop('lineno', None)
-        p[0] = ast.Figure(self, _.pop('paths'), **_)
+        if _.keys() == ['paths']:
+            p[0] = ast.Path(self, p.lineno(1), ".".join(_['paths']))
+        else:
+            p[0] = ast.Figure(self, _.pop('paths'), **_)
 
     def p_figure_with(self, p):
         '''figure : offit  PATH WITH figaggexp location figexps time
                   |        PATH WITH figaggexp location figexps time
                   | offit  PATH WITH figaggexp location               time
                   |        PATH WITH figaggexp location               time'''
-                  # need to support     figaggexps here...
         _ = dict(agg="count", # DEFAULT
                  limit=1, # DEFAULT
                  lineno=p.lineno(2))
@@ -374,7 +370,8 @@ class Parser(object):
     # -----------
     def p_stmt_while(self, p):
         '''stmt : WHILE paths               output suite
-                | WHILE expressions         output suite'''
+                | WHILE expressions         output suite
+                | WHILE figure_expression   output suite'''
         p[0] = ast.Method("while", parser=self, lineno=p.lineno(1), output=p[3], suite=p[4], args=(p[2], ))
 
     # -----------
